django\_sorcery.management.commands.sorcery\_createall module
=============================================================

.. automodule:: django_sorcery.management.commands.sorcery_createall
    :members:
    :undoc-members:
    :show-inheritance:
